@@ -1,9 +1,8 @@
 #!/usr/bin/env perl
 
 use strict;
-use utf8;
 use warnings;
-use open qw(:std :utf8); # Undeclared streams in UTF-8.
+use warnings qw(FATAL utf8); # Fatalize encoding glitches.
 
 use Getopt::Long;
 
@@ -20,7 +19,6 @@ my(%option);
 if ($option_parser -> getoptions
 (
 	\%option,
-	'encoding=s',
 	'help',
 	'input_file_name=s',
 	'maxlevel=s',
@@ -50,7 +48,6 @@ parse.file.pl - Parsing any SVG file
 test.file.pl [options]
 
 	Options:
-	-encoding aString
 	-help
 	-input_file_name anSVGFileName
 	-maxlevel aString
@@ -65,14 +62,6 @@ Exit value: 0.
 
 =over 4
 
-=item o -encoding aString
-
-String takes values such as 'utf-8', and the code converts this into '<:encoding(utf-8)'.
-
-This option is rarely needed for input, but may be for output.
-
-Default: ''.
-
 =item o -help
 
 Print help and exit.
